@@ -38,14 +38,14 @@
 ****************************************************************************/
 
 
-#include <QtPositioning/private/qdeclarativegeoaddress_p.h>
-#include <QtPositioning/private/qdeclarativegeolocation_p.h>
+#include <QtPositioningQuick/private/qdeclarativegeoaddress_p.h>
+#include <QtPositioningQuick/private/qdeclarativegeolocation_p.h>
 #include <QtPositioning/private/qwebmercator_p.h>
-
-#include <QtPositioningQuick/private/qdeclarativepositionsource_p.h>
 #include <QtPositioningQuick/private/qdeclarativeposition_p.h>
+#include <QtPositioningQuick/private/qdeclarativepositionsource_p.h>
+#include <QtPositioningQuick/private/qdeclarativepluginparameter_p.h>
 
-#include "qquickgeocoordinateanimation_p.h"
+#include <QtPositioningQuick/private/qquickgeocoordinateanimation_p.h>
 #include "locationsingleton.h"
 
 #include <QtCore/QVariantAnimation>
@@ -62,13 +62,6 @@
 
 #include <QtCore/QDebug>
 
-static void initResources()
-{
-#ifdef QT_STATIC
-    Q_INIT_RESOURCE(qmake_QtPositioning);
-#endif
-}
-
 QT_BEGIN_NAMESPACE
 
 /*!
@@ -558,8 +551,8 @@ QT_BEGIN_NAMESPACE
 
 static QObject *singleton_type_factory(QQmlEngine *engine, QJSEngine *jsEngine)
 {
-    Q_UNUSED(engine)
-    Q_UNUSED(jsEngine)
+    Q_UNUSED(engine);
+    Q_UNUSED(jsEngine);
 
     return new LocationSingleton;
 }
@@ -572,7 +565,7 @@ class QtPositioningDeclarativeModule: public QQmlExtensionPlugin
                       FILE "plugin.json")
 
 public:
-    QtPositioningDeclarativeModule(QObject *parent = 0) : QQmlExtensionPlugin(parent) { initResources(); }
+    QtPositioningDeclarativeModule(QObject *parent = 0) : QQmlExtensionPlugin(parent) { }
     virtual void registerTypes(const char *uri)
     {
         if (QLatin1String(uri) == QStringLiteral("QtPositioning")) {
@@ -620,6 +613,12 @@ public:
             minor = 4;
             qmlRegisterType<QDeclarativePosition, 2>(uri, major, minor, "Position");
 
+            minor = 13;
+            qmlRegisterType<QDeclarativeGeoLocation, 13>(uri, major, minor, "Location");
+
+            minor = 14;
+            qmlRegisterType<QDeclarativePluginParameter >(uri, major, minor, "PluginParameter");
+
             // Register the latest Qt version as QML type version
             qmlRegisterModule(uri, QT_VERSION_MAJOR, QT_VERSION_MINOR);
         } else {
@@ -628,6 +627,6 @@ public:
     }
 };
 
-#include "positioning.moc"
-
 QT_END_NAMESPACE
+
+#include "positioning.moc"
